#/bin/sh
# 
# Test system for U.S. 2007 daylight saving issues
#
#OLDPWD=$(pwd)
echo "Licensed under the Open Software License version 2.1 "
echo "    See full license agreement in the readme.txt"
echo " "
sleep 15
WHATOS=`uname -a | awk '{ print $1 }'`
CURR="v012"            # Update this value for each new version of this script.
CWD=`dirname "$0"`
cd $CWD 
if [ ! "$TZ" ]
then
    DEFTZ=`date +%Z`
else
    OLDTZ=$TZ
    DEFTZ=$TZ
fi
#
echo "Daylight Savings Time (DST) test script Version: $CURR " 
echo Testing system  `uname -a | awk '{ print $2 }'`  started `date`
#echo " "
#echo "Testing basic OS functions... For Timezone $DEFTZ"
if [ -f ./dst ]
then
   echo "DST executable already built, continuing..."
   echo " "
else
   echo "Building DST executable..."
   cc -o dst dst.c
fi
echo " "
echo "Testing default OS Daylight Savings Time functions for"
echo "U.S. or Canada 2007 change."
echo " "
OSRESULTS=" SUCCESS! - OS is 2007 DST Ready!"
echo "Testing basic OS functions... For local Timezone $DEFTZ"
echo " "
#
LOCALCRESULTS=0
NASSAUCRESULTS=0
CANADACRESULTS=0
EASTERNCRESULTS=0
./dst
if [ $? -gt 0 ] 
then
    LOCALCRESULTS=1
         echo "Note: If your default timezone is not U.S. or Canada"
         echo "      Please ignore this failure." 
fi
echo " "
#TZ=EST5EDT#nassau
#echo "Testing basic OS functions... For Timezone $TZ (Nassau)"
#echo " "
#
#./dst
#if [ $? -gt 0 ] 
#then
#    NASSAUCRESULTS=1
#fi
echo " "
#if [ "$WHATOS" = "HP-UX" ]
#then
#TZ=AST4ADT#Canada
#else
TZ=AST4AST
#fi
echo "Testing basic OS functions... For Timezone $TZ (Canada)"
echo " "
#
./dst
if [ $? -gt 0 ] 
then
    CANADACRESULTS=1
fi
#
echo " "
TZ=EST5EDT
echo "Testing basic OS functions... For Timezone $TZ (U.S)"
echo " "
#
./dst
if [ $? -gt 0 ] 
then
    EASTERNCRESULTS=1
fi
#
echo " "
if [ ! "$OLDTZ" ]
then
    TZ=$OLDTZ
else
    TZ=
fi
if [ "$WHATOS" = "HP-UX" ]
then
echo "Checking for aC++ shared libraries and executables from / "
#if [ -f /tmp/accprogsfound ]
#then
#echo "     Already gathered for this system, using previous information"
#else
echo "Excluding /opt /usr /var and nfs dirs this will take time..."
echo "   depending on the file system this could take 45 minutes to 3 hours"
./FindAccPrograms /  >/tmp/accprogsfound
#fi
CPPRESULTS=`wc -l /tmp/accprogsfound | awk '{print $1}'`
echo "done"
echo " "
echo "Checking for stripped shared libraries and executables from / "
#if [ -f /tmp/accprogsfound ]
#then
#echo "     Already gathered for this system, using previous information"
#else
echo "Excluding /opt /usr /var and nfs dirs this will take time..."
./FindStrippedPrograms /tmp/listofprograms >/tmp/strippedprogsfound
#fi
STRIPPEDRESULTS=`wc -l /tmp/strippedprogsfound | awk '{print $1}'`
#if [ -f /usr/bin/Acc ]
#then
#   echo "TBS add c++ test here."
#else
#   echo "  C++ is not installed on this system."
#   echo " "
#fi
#
# end of HP-UX only test
fi
DSTSUMMARYFILE=/tmp/DSTSUMMARYFILE.$$
echo "0 0 0 0" > $DSTSUMMARYFILE
echo " "
echo "Searching/Testing Java..."
echo " "
echo "  Searching for Java from "/" (Excluding NFS mounted file systems.)"
echo "  This might take a while, Thank You for your patience..."
echo " "
echo " "
/usr/bin/find / -fstype nfs -prune -o -fstype autofs -prune -o -name java -exec  $CWD/test_java.sh {} $DSTSUMMARYFILE \;
echo " "
echo " "
echo "Daylight Savings Time testing completed. "
echo " "
echo " "
echo "  Daylight Savings Time Test Summary:"
echo "  ==================================="
echo " "
if [ "$WHATOS" = "HP-UX" ]
then
echo "         C++ Programs and shared libraries found:     $CPPRESULTS" 
echo "         NOTE: The below programs are suspected to have liba++ or librwtool objects" 
echo "               In these cases installing aCC patches and relinking static linked programs"
echo "               programs is recommended."
echo " "
cat /tmp/accprogsfound
echo " "
echo " "
cat /tmp/accprogsfound | xargs nm -PxAN 2>/tmp/nmerrors  | grep -e [a-z,A-Z]4Time -e [a-z,A-Z]5Place | cut -f1 -d":" |  cut -f1 -d "[" | sort | uniq >/tmp/lib++progs 
CPPRESULTS=`wc -l /tmp/lib++progs | awk '{print $1}'`
echo "         Potential lib++ Programs and shared libraries found:     $CPPRESULTS" 
echo " "
echo " "
cat /tmp/lib++progs
echo " "
echo " "
cat /tmp/accprogsfound | xargs nm -PxAN 2>/tmp/nmerrors  | grep -e 6RWTime -e 6RWZone | cut -f1 -d":" |  cut -f1 -d "[" | sort | uniq >/tmp/librwprogs 
CPPRESULTS=`wc -l /tmp/librwprogs | awk '{print $1}'`
echo "         Potential librwtool Programs and shared libraries found:     $CPPRESULTS" 
echo " "
echo " "
cat /tmp/librwprogs
echo " "
echo " "
echo "         Stripped Programs and shared libraries found:     $STRIPPEDRESULTS" 
echo "         NOTE: Stripped Programs will need to be checked manually. Try locating Makefiles"
echo "               known to be used to generate the program. Check NON-HP supplied Programs"
echo " "
echo " "
#cat /tmp/strippedprogsfound
cut -f1,3 -d":"  /tmp/strippedprogsfound |sed "s/nm://"
echo " "
# end of HP-UX only
fi
echo " "
echo "         OS Test Results:"
echo " "
if [ $LOCALCRESULTS -eq 0 ]
then
echo "                           Local TZ test  : Passed"
else
echo "                           Local TZ test  : Failed"
fi
#if [ $NASSAUCRESULTS -eq 0 ]
#then
#echo "                           Nassau TZ test : Passed"
#else
#echo "                           Nassau TZ test : Failed"
#fi
if [ $CANADACRESULTS -eq 0 ]
then
echo "                           Canada TZ test : Passed"
else
echo "                           Canada TZ test : Failed"
fi
if [ $EASTERNCRESULTS -eq 0 ]
then
echo "                           U.S. TZ test   : Passed"
else
echo "                           U.S. TZ test   : Failed"
fi
echo " "
JVMFOUND=`head -n 1 $DSTSUMMARYFILE | awk '{print $1}'`
JVMPASSED=`head -n 1 $DSTSUMMARYFILE | awk '{print $2}'`
JVMFAILED=`head -n 1 $DSTSUMMARYFILE | awk '{print $3}'`
JVMUNSUPPORTED=`head -n 1 $DSTSUMMARYFILE | awk '{print $4}'`
echo "         Java Test Summary:"
echo " "
echo "                        Versions found    :   $JVMFOUND"
echo "                     Versions DST Ready   :   $JVMPASSED"
echo "                 Versions Not DST Ready   :   $JVMFAILED"
echo "                 Versions Not Supported:  :   $JVMUNSUPPORTED"
echo " "
echo "Note-1: The NFS file systems were not reviewed!"
echo " "
export TZ=$DEFTZ
rm $DSTSUMMARYFILE
echo Testing completed `date`
